==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/Line2P/ts/Line2P_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Line2P</name>
    <message>
        <location filename="../Line2P.js" line="+67"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation type="unfinished">Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next point</source>
        <translatorcomment>--google--
Wskaż następny punkt
Wskaż następny punkt lub [%1]
Wskaż następny punkt wieloboku</translatorcomment>
        <translation type="unfinished">Następny punkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location filename="../Line2P.ui" line="+23"/>
        <source>Close Sequence</source>
        <translatorcomment>--google--
Nie można zamknąć sekwencji linii: niewystarczająca liczba zdefiniowanych obiektów.
Nie można zamknąć sekwencji linii: niewystarczająca liczba zdefiniowanych obiektów</translatorcomment>
        <translation type="unfinished">Zamknij Sequence</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Cofnąć poprzedni segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Restrict length or angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Line2PInit.js" line="+2"/>
        <source>Line from &amp;2 Points</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Linia z 2 punktów</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw single line or sequence of lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysuj jeden wiersz lub sekwencję linii</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/Line2P/ts/Line2P_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Line2P</name>
    <message>
        <location filename="../Line2P.js" line="+67"/>
        <source>First point</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt
Wskaż pierwszy punkt wieloboku
Wskaż pierwszy punkt odległości</translatorcomment>
        <translation>Pierwszy punkt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next point</source>
        <translatorcomment>--google--
Wskaż następny punkt
Wskaż następny punkt lub [%1]
Wskaż następny punkt wieloboku</translatorcomment>
        <translation>Następny punkt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location filename="../Line2P.ui" line="+23"/>
        <source>Close Sequence</source>
        <translatorcomment>--google--
Nie można zamknąć sekwencji linii: niewystarczająca liczba zdefiniowanych obiektów.
Nie można zamknąć sekwencji linii: niewystarczająca liczba zdefiniowanych obiektów</translatorcomment>
        <translation>Zamknij sekwencję</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, C</source>
        <translation>,, C</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Undo Previous Segment</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cofnij poprzedni segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, U</source>
        <translation>,, U</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Redo Segment</source>
        <translation>Ponów segment</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>,, R</source>
        <translation>,, R</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Restrict length or angle</source>
        <translation>Ogranicz długość lub kąt</translation>
    </message>
    <message>
        <location filename="../Line2PInit.js" line="+2"/>
        <source>Line from &amp;2 Points</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linia z &amp;2 punktów</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw single line or sequence of lines</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje jedną linię lub sekwencję linii</translation>
    </message>
</context>
</TS>
